@@ -10,6 +10,7 @@
 # pylint: disable=no-name-in-module
 """Tests to run with a running daemon."""
 import os
+import re
 import shutil
 import subprocess
 import sys
@@ -135,6 +136,12 @@ def validate_calculations(expected_results):
             # If the retrieval fails we simply pass as the following check of the actual value will fail anyway
             pass
 
+        # Convert the parsed stdout content (which should be the integer followed by a newline `10\n`) to an integer
+        try:
+            actual_dict['value'] = int(actual_dict['value'].strip())
+        except (KeyError, ValueError):
+            pass
+
         if actual_dict != expected_dict:
             print(f'* UNEXPECTED VALUE {actual_dict} for calc pk={pk}: I expected {expected_dict}')
             valid = False
@@ -308,7 +315,7 @@ def create_calculation_process(code, inputval):
         },
         'max_wallclock_seconds': 5 * 60,
         'withmpi': False,
-        'parser_name': 'core.templatereplacer.doubler',
+        'parser_name': 'core.templatereplacer',
     }
 
     expected_result = {'value': 2 * inputval, 'retrieved_temporary_files': {'triple_value.tmp': str(inputval * 3)}}
@@ -434,7 +441,7 @@ def launch_all():
         # Delete the temporary directory to test that the stashing functionality will create it if necessary
         shutil.rmtree(tmpdir, ignore_errors=True)
 
-        source_list = ['output.txt', 'triple_value.tmp']
+        source_list = ['output.txt', 'triple_value.*']
         inputs['metadata']['options']['stash'] = {'target_base': tmpdir, 'source_list': source_list}
         _, node = run.get_node(process, **inputs)
         assert node.is_finished_ok
@@ -443,7 +450,13 @@ def launch_all():
         assert remote_stash.stash_mode == StashMode.COPY
         assert remote_stash.target_basepath.startswith(tmpdir)
         assert sorted(remote_stash.source_list) == sorted(source_list)
-        assert sorted(p for p in os.listdir(remote_stash.target_basepath)) == sorted(source_list)
+
+        stashed_filenames = os.listdir(remote_stash.target_basepath)
+        for filename in source_list:
+            if '*' in filename:
+                assert any(re.match(filename, stashed_file) is not None for stashed_file in stashed_filenames)
+            else:
+                assert filename in stashed_filenames
 
     # Submitting the calcfunction through the launchers
     print('Submitting calcfunction to the daemon')
