@@ -8,70 +8,37 @@
 # For further information please visit http://www.aiida.net               #
 ###########################################################################
 """Common password and hash generation functions."""
-import datetime
-import hashlib
-import numbers
-import random
-import time
-import uuid
-from collections import abc, OrderedDict
+from collections import OrderedDict, abc
+from datetime import date, datetime, timezone
+from decimal import Decimal
 from functools import singledispatch
+import hashlib
 from itertools import chain
+import numbers
 from operator import itemgetter
-
-import pytz
+import secrets
+import string
+import typing
+import uuid
 
 from aiida.common.constants import AIIDA_FLOAT_PRECISION
 from aiida.common.exceptions import HashingError
+from aiida.common.utils import DatetimePrecision
 
 from .folders import Folder
 
-# The prefix of the hashed using pbkdf2_sha256 algorithm in Django
-HASHING_PREFIX_DJANGO = 'pbkdf2_sha256'
-# The prefix of the hashed using pbkdf2_sha256 algorithm in Passlib
-HASHING_PREFIX_PBKDF2_SHA256 = '$pbkdf2-sha256'
 
-# This will never be a valid encoded hash
-UNUSABLE_PASSWORD_PREFIX = '!'  # noqa
-# Number of random chars to add after UNUSABLE_PASSWORD_PREFIX
-UNUSABLE_PASSWORD_SUFFIX_LENGTH = 40
+def get_random_string(length: int = 12) -> str:
+    """Return a securely generated random string.
 
-HASHING_KEY = 'HashingKey'
+    The default length of 12 with the all ASCII letters and digits returns a 71-bit value:
 
-# The key that is used to store the hash in the node extras
-_HASH_EXTRA_KEY = '_aiida_hash'
+        log_2((26+26+10)^12) =~ 71 bits
 
-###################################################################
-# THE FOLLOWING WAS TAKEN FROM DJANGO BUT IT CAN BE EASILY REPLACED
-###################################################################
-
-# Use the system PRNG if possible
-try:
-    # pylint: disable=invalid-name
-    random = random.SystemRandom()
-    using_sysrandom = True
-except NotImplementedError:
-    import warnings
-    warnings.warn('A secure pseudo-random number generator is not available. Falling back to Mersenne Twister.')  # pylint: disable=no-member
-    using_sysrandom = False  # pylint: disable=invalid-name
-
-
-def get_random_string(length=12, allowed_chars='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'):
+    :param length: The number of characters to use for the string.
     """
-    Returns a securely generated random string.
-
-    The default length of 12 with the a-z, A-Z, 0-9 character set returns
-    a 71-bit value. log_2((26+26+10)^12) =~ 71 bits
-    """
-    if not using_sysrandom:
-        # This is ugly, and a hack, but it makes things better than
-        # the alternative of predictability. This re-seeds the PRNG
-        # using a value that is hard for an attacker to predict, every
-        # time a random string is required. This may change the
-        # properties of the chosen random sequence slightly, but this
-        # is better than absolute predictability.
-        random.seed(hashlib.sha256(f'{random.getstate()}{time.time()}{HASHING_KEY}'.encode('utf-8')).digest())
-    return ''.join(random.choice(allowed_chars) for i in range(length))
+    alphabet = string.ascii_letters + string.digits
+    return ''.join(secrets.choice(alphabet) for i in range(length))
 
 
 BLAKE2B_OPTIONS = {
@@ -82,6 +49,31 @@ BLAKE2B_OPTIONS = {
 }
 
 
+def chunked_file_hash(
+    handle: typing.BinaryIO, hash_cls: typing.Any, chunksize: int = 524288, **kwargs: typing.Any
+) -> str:
+    """Return the hash for the given file handle
+
+    Will read the file in chunks, which should be opened in 'rb' mode.
+
+    :param handle: a file handle, opened in 'rb' mode.
+    :param hash_cls: a class implementing hashlib._Hash
+    :param chunksize: number of bytes to chunk the file read in
+    :param kwargs: arguments to pass to the hasher initialisation
+    :return: the hash hexdigest (the hash key)
+    """
+    hasher = hash_cls(**kwargs)
+    while True:
+        chunk = handle.read(chunksize)
+        hasher.update(chunk)
+
+        if not chunk:
+            # Empty returned value: EOF
+            break
+
+    return hasher.hexdigest()
+
+
 def make_hash(object_to_hash, **kwargs):
     """
     Makes a hash from a dictionary, list, tuple or set to any level, that contains
@@ -196,11 +188,24 @@ def _(mapping, **kwargs):
 def _(val, **kwargs):
     """
     Before hashing a float, convert to a string (via rounding) and with a fixed number of digits after the comma.
-    Note that the `_singe_digest` requires a bytes object so we need to encode the utf-8 string first
+    Note that the `_single_digest` requires a bytes object so we need to encode the utf-8 string first
     """
     return [_single_digest('float', float_to_text(val, sig=AIIDA_FLOAT_PRECISION).encode('utf-8'))]
 
 
+@_make_hash.register(Decimal)
+def _(val, **kwargs):
+    """
+    While a decimal can be converted exactly to a string which captures all characteristics of the underlying
+    implementation, we also need compatibility with "equal" representations as int or float. Hence we are checking
+    for the exponent (which is negative if there is a fractional component, 0 otherwise) and get the same hash
+    as for a corresponding float or int.
+    """
+    if val.as_tuple().exponent < 0:
+        return [_single_digest('float', float_to_text(val, sig=AIIDA_FLOAT_PRECISION).encode('utf-8'))]
+    return [_single_digest('int', f'{val}'.encode('utf-8'))]
+
+
 @_make_hash.register(numbers.Complex)
 def _(val, **kwargs):
     """
@@ -231,18 +236,18 @@ def _(val, **kwargs):
     return [_single_digest('none')]
 
 
-@_make_hash.register(datetime.datetime)
+@_make_hash.register(datetime)
 def _(val, **kwargs):
     """hashes the little-endian rep of the float <epoch-seconds>.<subseconds>"""
     # see also https://stackoverflow.com/a/8778548 for an excellent elaboration
     if val.tzinfo is None or val.utcoffset() is None:
-        val = val.replace(tzinfo=pytz.utc)
+        val = val.replace(tzinfo=timezone.utc)
 
     timestamp = val.timestamp()
     return [_single_digest('datetime', float_to_text(timestamp, sig=AIIDA_FLOAT_PRECISION).encode('utf-8'))]
 
 
-@_make_hash.register(datetime.date)
+@_make_hash.register(date)
 def _(val, **kwargs):
     """Hashes the string representation in ISO format of the `datetime.date` object."""
     return [_single_digest('date', val.isoformat().encode('utf-8'))]
@@ -253,6 +258,15 @@ def _(val, **kwargs):
     return [_single_digest('uuid', val.bytes)]
 
 
+@_make_hash.register(DatetimePrecision)
+def _(datetime_precision, **kwargs):
+    """ Hashes for DatetimePrecision object
+    """
+    return [_single_digest('dt_prec')] + list(
+        chain.from_iterable(_make_hash(i, **kwargs) for i in [datetime_precision.dtobj, datetime_precision.precision])
+    ) + [_END_DIGEST]
+
+
 @_make_hash.register(Folder)
 def _(folder, **kwargs):
     """
