@@ -9,23 +9,29 @@
 ###########################################################################
 """Module for all logging methods/classes that don't need the ORM."""
 import collections
-import copy
+import contextlib
 import logging
 import types
-from contextlib import contextmanager
-from wrapt import decorator
 
-from aiida.manage.configuration import get_config_option
-
-__all__ = ('AIIDA_LOGGER', 'override_log_level', 'override_log_formatter')
+__all__ = ('AIIDA_LOGGER', 'override_log_level')
 
 # Custom logging level, intended specifically for informative log messages reported during WorkChains.
 # We want the level between INFO(20) and WARNING(30) such that it will be logged for the default loglevel, however
 # the value 25 is already reserved for SUBWARNING by the multiprocessing module.
-
 LOG_LEVEL_REPORT = 23
+
+# Add the custom log level to the :mod:`logging` module and add a corresponding report logging method.
 logging.addLevelName(LOG_LEVEL_REPORT, 'REPORT')
 
+
+def report(self, msg, *args, **kwargs):
+    """Log a message at the ``REPORT`` level."""
+    self.log(LOG_LEVEL_REPORT, msg, *args, **kwargs)
+
+
+setattr(logging, 'REPORT', LOG_LEVEL_REPORT)
+setattr(logging.Logger, 'report', report)
+
 # Convenience dictionary of available log level names and their log level integer
 LOG_LEVELS = {
     logging.getLevelName(logging.NOTSET): logging.NOTSET,
@@ -37,88 +43,87 @@ LOG_LEVELS = {
     logging.getLevelName(logging.CRITICAL): logging.CRITICAL,
 }
 
-# The AiiDA logger
 AIIDA_LOGGER = logging.getLogger('aiida')
-
-
-# A logging filter that can be used to disable logging
-class NotInTestingFilter(logging.Filter):
-
-    def filter(self, record):
-        from aiida.manage import configuration
-        return not configuration.PROFILE.is_test_profile
+CLI_LOG_LEVEL = None
 
 
 # The default logging dictionary for AiiDA that can be used in conjunction
 # with the config.dictConfig method of python's logging module
-LOGGING = {
-    'version': 1,
-    'disable_existing_loggers': False,
-    'formatters': {
-        'verbose': {
-            'format': '%(levelname)s %(asctime)s %(module)s %(process)d '
-            '%(thread)d %(message)s',
+def get_logging_config():
+    from aiida.manage.configuration import get_config_option
+
+    return {
+        'version': 1,
+        'disable_existing_loggers': False,
+        'formatters': {
+            'verbose': {
+                'format': '%(levelname)s %(asctime)s %(module)s %(process)d '
+                '%(thread)d %(message)s',
+            },
+            'halfverbose': {
+                'format': '%(asctime)s <%(process)d> %(name)s: [%(levelname)s] %(message)s',
+                'datefmt': '%m/%d/%Y %I:%M:%S %p',
+            },
+            'cli': {
+                'class': 'aiida.cmdline.utils.log.CliFormatter'
+            }
         },
-        'halfverbose': {
-            'format': '%(asctime)s <%(process)d> %(name)s: [%(levelname)s] %(message)s',
-            'datefmt': '%m/%d/%Y %I:%M:%S %p',
+        'handlers': {
+            'console': {
+                'class': 'logging.StreamHandler',
+                'formatter': 'halfverbose',
+            },
+            'cli': {
+                'class': 'aiida.cmdline.utils.log.CliHandler',
+                'formatter': 'cli',
+            }
         },
-    },
-    'filters': {
-        'testing': {
-            '()': NotInTestingFilter
-        }
-    },
-    'handlers': {
-        'console': {
-            'level': 'DEBUG',
-            'class': 'logging.StreamHandler',
-            'formatter': 'halfverbose',
-            'filters': ['testing']
+        'loggers': {
+            'aiida': {
+                'handlers': ['console'],
+                'level': lambda: get_config_option('logging.aiida_loglevel'),
+                'propagate': True,
+            },
+            'aiida.cmdline': {
+                'handlers': ['cli'],
+                'propagate': False,
+            },
+            'plumpy': {
+                'handlers': ['console'],
+                'level': lambda: get_config_option('logging.plumpy_loglevel'),
+                'propagate': False,
+            },
+            'kiwipy': {
+                'handlers': ['console'],
+                'level': lambda: get_config_option('logging.kiwipy_loglevel'),
+                'propagate': False,
+            },
+            'paramiko': {
+                'handlers': ['console'],
+                'level': lambda: get_config_option('logging.paramiko_loglevel'),
+                'propagate': False,
+            },
+            'alembic': {
+                'handlers': ['console'],
+                'level': lambda: get_config_option('logging.alembic_loglevel'),
+                'propagate': False,
+            },
+            'aio_pika': {
+                'handlers': ['console'],
+                'level': lambda: get_config_option('logging.aiopika_loglevel'),
+                'propagate': False,
+            },
+            'sqlalchemy': {
+                'handlers': ['console'],
+                'level': lambda: get_config_option('logging.sqlalchemy_loglevel'),
+                'propagate': False,
+                'qualname': 'sqlalchemy.engine',
+            },
+            'py.warnings': {
+                'handlers': ['console'],
+            },
         },
-    },
-    'loggers': {
-        'aiida': {
-            'handlers': ['console'],
-            'level': lambda: get_config_option('logging.aiida_loglevel'),
-            'propagate': False,
-        },
-        'plumpy': {
-            'handlers': ['console'],
-            'level': lambda: get_config_option('logging.plumpy_loglevel'),
-            'propagate': False,
-        },
-        'kiwipy': {
-            'handlers': ['console'],
-            'level': lambda: get_config_option('logging.kiwipy_loglevel'),
-            'propagate': False,
-        },
-        'paramiko': {
-            'handlers': ['console'],
-            'level': lambda: get_config_option('logging.paramiko_loglevel'),
-            'propagate': False,
-        },
-        'alembic': {
-            'handlers': ['console'],
-            'level': lambda: get_config_option('logging.alembic_loglevel'),
-            'propagate': False,
-        },
-        'aio_pika': {
-            'handlers': ['console'],
-            'level': lambda: get_config_option('logging.aiopika_loglevel'),
-            'propagate': False,
-        },
-        'sqlalchemy': {
-            'handlers': ['console'],
-            'level': lambda: get_config_option('logging.sqlalchemy_loglevel'),
-            'propagate': False,
-            'qualname': 'sqlalchemy.engine',
-        },
-        'py.warnings': {
-            'handlers': ['console'],
-        },
-    },
-}
+    }
 
 
 def evaluate_logging_configuration(dictionary):
@@ -149,15 +154,19 @@ def configure_logging(with_orm=False, daemon=False, daemon_log_file=None):
     will cause a 'daemon_handler' to be added to all the configured loggers, that is a
     RotatingFileHandler that writes to the log file.
 
+    :param with_orm: configure logging to the backend storage.
+        We don't configure this by default, since it would load the modules that slow the CLI
     :param daemon: configure the logging for a daemon task by adding a file handler instead
         of the default 'console' StreamHandler
     :param daemon_log_file: absolute filepath of the log file for the RotatingFileHandler
     """
     from logging.config import dictConfig
 
+    from aiida.manage.configuration import get_config_option
+
     # Evaluate the `LOGGING` configuration to resolve the lambdas that will retrieve the correct values based on the
-    # currently configured profile. Pass a deep copy of `LOGGING` to ensure that the original remains unaltered.
-    config = evaluate_logging_configuration(copy.deepcopy(LOGGING))
+    # currently configured profile.
+    config = evaluate_logging_configuration(get_logging_config())
     daemon_handler_name = 'daemon_log_file'
 
     # Add the daemon file handler to all loggers if daemon=True
@@ -188,6 +197,10 @@ def configure_logging(with_orm=False, daemon=False, daemon_log_file=None):
             except ValueError:
                 pass
 
+    if CLI_LOG_LEVEL is not None:
+        config['loggers']['aiida']['handlers'] = ['cli']
+        config['loggers']['aiida']['level'] = CLI_LOG_LEVEL
+
     # Add the `DbLogHandler` if `with_orm` is `True`
     if with_orm:
 
@@ -202,7 +215,7 @@ def configure_logging(with_orm=False, daemon=False, daemon_log_file=None):
     dictConfig(config)
 
 
-@contextmanager
+@contextlib.contextmanager
 def override_log_level(level=logging.CRITICAL):
     """Temporarily adjust the log-level of logger."""
     logging.disable(level=level)
@@ -210,38 +223,3 @@ def override_log_level(level=logging.CRITICAL):
         yield
     finally:
         logging.disable(level=logging.NOTSET)
-
-
-@contextmanager
-def override_log_formatter_context(fmt: str):
-    """Temporarily use a different formatter for all handlers.
-
-    NOTE: One can _only_ set `fmt` (not `datefmt` or `style`).
-    """
-    temp_formatter = logging.Formatter(fmt=fmt)
-    cached_formatters = {}
-
-    for handler in AIIDA_LOGGER.handlers:
-        # Need a copy here so we keep the original one should the handler's formatter be changed during the yield
-        cached_formatters[handler] = copy.copy(handler.formatter)
-        handler.setFormatter(temp_formatter)
-
-    yield
-
-    for handler, formatter in cached_formatters.items():
-        handler.setFormatter(formatter)
-
-
-def override_log_formatter(fmt: str):
-    """Temporarily use a different formatter for all handlers.
-
-    NOTE: One can _only_ set `fmt` (not `datefmt` or `style`).
-    Be aware! This may fail if the number of handlers is changed within the decorated function/method.
-    """
-
-    @decorator
-    def wrapper(wrapped, instance, args, kwargs):  # pylint: disable=unused-argument
-        with override_log_formatter_context(fmt=fmt):
-            return wrapped(*args, **kwargs)
-
-    return wrapper
