@@ -194,7 +194,7 @@ class CalcJob(Process):
         # yapf: disable
         super().define(spec)
         spec.inputs.validator = validate_calc_job  # type: ignore[assignment]  # takes only PortNamespace not Port
-        spec.input('code', valid_type=orm.Code, required=False,
+        spec.input('code', valid_type=orm.AbstractCode, required=False,
             help='The `Code` to use for this job. This input is required, unless the `remote_folder` input is '
                  'specified, which means an existing job is being imported and no code will actually be run.')
         spec.input('remote_folder', valid_type=orm.RemoteData, required=False,
@@ -283,14 +283,20 @@ class CalcJob(Process):
             help='Files that are retrieved by the daemon will be stored in this node. By default the stdout and stderr '
                  'of the scheduler will be added, but one can add more by specifying them in `CalcInfo.retrieve_list`.')
 
-        # Errors caused or returned by the scheduler
-        spec.exit_code(100, 'ERROR_NO_RETRIEVED_FOLDER',
-            message='The process did not have the required `retrieved` output.')
-        spec.exit_code(110, 'ERROR_SCHEDULER_OUT_OF_MEMORY',
-            message='The job ran out of memory.')
-        spec.exit_code(120, 'ERROR_SCHEDULER_OUT_OF_WALLTIME',
-            message='The job ran out of walltime.')
         # yapf: enable
+        # Errors caused or returned by the scheduler
+        spec.exit_code(
+            100,
+            'ERROR_NO_RETRIEVED_FOLDER',
+            invalidates_cache=True,
+            message='The process did not have the required `retrieved` output.'
+        )
+        spec.exit_code(
+            110, 'ERROR_SCHEDULER_OUT_OF_MEMORY', invalidates_cache=True, message='The job ran out of memory.'
+        )
+        spec.exit_code(
+            120, 'ERROR_SCHEDULER_OUT_OF_WALLTIME', invalidates_cache=True, message='The job ran out of walltime.'
+        )
 
     @classproperty
     def spec_options(cls):  # pylint: disable=no-self-argument
@@ -396,6 +402,29 @@ class CalcJob(Process):
         """
         raise NotImplementedError()
 
+    def _setup_metadata(self, metadata: dict) -> None:
+        """Store the metadata on the ProcessNode."""
+        computer = metadata.pop('computer', None)
+        if computer is not None:
+            self.node.computer = computer
+
+        options = metadata.pop('options', {})
+        for option_name, option_value in options.items():
+            self.node.set_option(option_name, option_value)
+
+        super()._setup_metadata(metadata)
+
+    def _setup_inputs(self) -> None:
+        """Create the links between the input nodes and the ProcessNode that represents this process."""
+        super()._setup_inputs()
+
+        # If a computer has not yet been set, which should have been done in ``_setup_metadata`` if it was specified
+        # in the ``metadata`` inputs, set the computer associated with the ``code`` input. Note that not all ``code``s
+        # will have an associated computer, but in that case the ``computer`` property should return ``None`` and
+        # nothing would change anyway.
+        if not self.node.computer:
+            self.node.computer = self.inputs.code.computer  # type: ignore[union-attr]
+
     def _perform_dry_run(self):
         """Perform a dry run.
 
@@ -429,11 +458,14 @@ class CalcJob(Process):
         from aiida.common.datastructures import CalcJobState
         from aiida.common.folders import SandboxFolder
         from aiida.engine.daemon.execmanager import retrieve_calculation
+        from aiida.manage import get_config_option
         from aiida.transports.plugins.local import LocalTransport
 
+        filepath_sandbox = get_config_option('storage.sandbox') or None
+
         with LocalTransport() as transport:
-            with SandboxFolder() as folder:
-                with SandboxFolder() as retrieved_temporary_folder:
+            with SandboxFolder(filepath_sandbox) as folder:
+                with SandboxFolder(filepath_sandbox) as retrieved_temporary_folder:
                     self.presubmit(folder)
                     self.node.set_remote_workdir(
                         self.inputs.remote_folder.get_remote_path()  # type: ignore[union-attr]
@@ -589,7 +621,7 @@ class CalcJob(Process):
         from aiida.common.datastructures import CodeInfo, CodeRunMode
         from aiida.common.exceptions import InputValidationError, InvalidOperation, PluginInternalError, ValidationError
         from aiida.common.utils import validate_list_of_string_tuples
-        from aiida.orm import Code, Computer, load_node
+        from aiida.orm import AbstractCode, Computer, load_code
         from aiida.schedulers.datastructures import JobTemplate, JobTemplateCodeInfo
 
         inputs = self.node.base.links.get_incoming(link_type=LinkType.INPUT_CALC)
@@ -598,20 +630,17 @@ class CalcJob(Process):
             raise InvalidOperation('calculation node is not stored.')
 
         computer = self.node.computer
-        codes = [_ for _ in inputs.all_nodes() if isinstance(_, Code)]
+        codes = [_ for _ in inputs.all_nodes() if isinstance(_, AbstractCode)]
 
         for code in codes:
-            if not code.can_run_on(computer):
+            if not code.can_run_on_computer(computer):
                 raise InputValidationError(
                     'The selected code {} for calculation {} cannot run on computer {}'.format(
                         code.pk, self.node.pk, computer.label
                     )
                 )
 
-            if code.is_local() and code.get_local_executable() in folder.get_content_list():
-                raise PluginInternalError(
-                    f'The plugin created a file {code.get_local_executable()} that is also the executable name!'
-                )
+            code.validate_working_directory(folder)
 
         calc_info = self.prepare_for_submission(folder)
         calc_info.uuid = str(self.node.uuid)
@@ -660,12 +689,12 @@ class CalcJob(Process):
         #   would return None, in which case the join method would raise
         #   an exception
         prepend_texts = [computer.get_prepend_text()] + \
-            [code.get_prepend_text() for code in codes] + \
+            [code.prepend_text for code in codes] + \
             [calc_info.prepend_text, self.node.get_option('prepend_text')]
         job_tmpl.prepend_text = '\n\n'.join(prepend_text for prepend_text in prepend_texts if prepend_text)
 
         append_texts = [self.node.get_option('append_text'), calc_info.append_text] + \
-            [code.get_append_text() for code in codes] + \
+            [code.append_text for code in codes] + \
             [computer.get_append_text()]
         job_tmpl.append_text = '\n\n'.join(append_text for append_text in append_texts if append_text)
 
@@ -693,7 +722,7 @@ class CalcJob(Process):
 
             if code_info.code_uuid is None:
                 raise PluginInternalError('CalcInfo should have the information of the code to be launched')
-            this_code = load_node(code_info.code_uuid, sub_classes=(Code,))
+            this_code = load_code(code_info.code_uuid)
 
             # To determine whether this code should be run with MPI enabled, we get the value that was set in the inputs
             # of the entire process, which can then be overwritten by the value from the `CodeInfo`. This allows plugins
@@ -708,16 +737,16 @@ class CalcJob(Process):
                 this_withmpi = code_info.withmpi
 
             if this_withmpi:
-                prepend_cmdline_params = mpi_args + extra_mpirun_params
+                prepend_cmdline_params = this_code.get_prepend_cmdline_params(mpi_args, extra_mpirun_params)
             else:
-                prepend_cmdline_params = []
+                prepend_cmdline_params = this_code.get_prepend_cmdline_params()
 
-            cmdline_params = [this_code.get_execname()] + (code_info.cmdline_params or [])
+            cmdline_params = this_code.get_executable_cmdline_params(code_info.cmdline_params)
 
             tmpl_code_info = JobTemplateCodeInfo()
             tmpl_code_info.prepend_cmdline_params = prepend_cmdline_params
             tmpl_code_info.cmdline_params = cmdline_params
-            tmpl_code_info.use_double_quotes = [computer.get_use_double_quotes(), this_code.get_use_double_quotes()]
+            tmpl_code_info.use_double_quotes = [computer.get_use_double_quotes(), this_code.use_double_quotes]
             tmpl_code_info.stdin_name = code_info.stdin_name
             tmpl_code_info.stdout_name = code_info.stdout_name
             tmpl_code_info.stderr_name = code_info.stderr_name
