@@ -11,6 +11,7 @@
 import asyncio
 import collections
 from collections.abc import Mapping
+import copy
 import enum
 import inspect
 import logging
@@ -114,10 +115,21 @@ class Process(plumpy.processes.Process):
         )
         spec.inputs.valid_type = orm.Data
         spec.inputs.dynamic = False  # Settings a ``valid_type`` automatically makes it dynamic, so we reset it again
-        spec.exit_code(1, 'ERROR_UNSPECIFIED', message='The process has failed with an unspecified error.')
-        spec.exit_code(2, 'ERROR_LEGACY_FAILURE', message='The process failed with legacy failure mode.')
-        spec.exit_code(10, 'ERROR_INVALID_OUTPUT', message='The process returned an invalid output.')
-        spec.exit_code(11, 'ERROR_MISSING_OUTPUT', message='The process did not register a required output.')
+        spec.exit_code(
+            1, 'ERROR_UNSPECIFIED', invalidates_cache=True, message='The process has failed with an unspecified error.'
+        )
+        spec.exit_code(
+            2, 'ERROR_LEGACY_FAILURE', invalidates_cache=True, message='The process failed with legacy failure mode.'
+        )
+        spec.exit_code(
+            10, 'ERROR_INVALID_OUTPUT', invalidates_cache=True, message='The process returned an invalid output.'
+        )
+        spec.exit_code(
+            11,
+            'ERROR_MISSING_OUTPUT',
+            invalidates_cache=True,
+            message='The process did not register a required output.'
+        )
 
     @classmethod
     def get_builder(cls) -> ProcessBuilder:
@@ -650,6 +662,16 @@ class Process(plumpy.processes.Process):
 
             output.store()
 
+    def _build_process_label(self) -> str:
+        """Construct the process label that should be set on ``ProcessNode`` instances for this process class.
+
+        .. note:: By default this returns the name of the process class itself. It can be overridden by ``Process``
+            subclasses to provide a more specific label.
+
+        :returns: The process label to use for ``ProcessNode`` instances.
+        """
+        return self.__class__.__name__
+
     def _setup_db_record(self) -> None:
         """
         Create the database record for this process and the links with respect to its inputs
@@ -668,7 +690,7 @@ class Process(plumpy.processes.Process):
 
         # Store important process attributes in the node proxy
         self.node.set_process_state(None)
-        self.node.set_process_label(self.__class__.__name__)
+        self.node.set_process_label(self._build_process_label())
         self.node.set_process_type(self.__class__.build_process_type())
 
         parent_calc = self.get_parent_calc()
@@ -684,27 +706,22 @@ class Process(plumpy.processes.Process):
             elif isinstance(self.node, orm.WorkflowNode):
                 self.node.base.links.add_incoming(parent_calc, LinkType.CALL_WORK, self.metadata.call_link_label)
 
-        self._setup_metadata()
+        self._setup_metadata(copy.copy(dict(self.inputs.metadata)))
         self._setup_inputs()
 
-    def _setup_metadata(self) -> None:
+    def _setup_metadata(self, metadata: dict) -> None:
         """Store the metadata on the ProcessNode."""
         version_info = self.runner.plugin_version_provider.get_version_info(self.__class__)
         self.node.base.attributes.set_many(version_info)
 
-        for name, metadata in self.metadata.items():
+        for name, value in metadata.items():
             if name in ['store_provenance', 'dry_run', 'call_link_label']:
                 continue
 
             if name == 'label':
-                self.node.label = metadata
+                self.node.label = value
             elif name == 'description':
-                self.node.description = metadata
-            elif name == 'computer':
-                self.node.computer = metadata
-            elif name == 'options':
-                for option_name, option_value in metadata.items():
-                    self.node.set_option(option_name, option_value)
+                self.node.description = value
             else:
                 raise RuntimeError(f'unsupported metadata key: {name}')
 
@@ -716,10 +733,6 @@ class Process(plumpy.processes.Process):
             if node is None:
                 continue
 
-            # Special exception: set computer if node is a remote Code and our node does not yet have a computer set
-            if isinstance(node, orm.Code) and not node.is_local() and not self.node.computer:
-                self.node.computer = node.get_remote_computer()
-
             # Need this special case for tests that use ProcessNodes as classes
             if isinstance(self.node, orm.CalculationNode):
                 self.node.base.links.add_incoming(node, LinkType.INPUT_CALC, name)
