@@ -18,19 +18,18 @@ from typing import Any, Callable, Dict, NamedTuple, Optional, Tuple, Type, Union
 import uuid
 
 import kiwipy
+from plumpy.communications import wrap_communicator
+from plumpy.events import reset_event_loop_policy, set_event_loop_policy
 from plumpy.persistence import Persister
 from plumpy.process_comms import RemoteProcessThreadController
-from plumpy.events import set_event_loop_policy, reset_event_loop_policy
-from plumpy.communications import wrap_communicator
 
 from aiida.common import exceptions
-from aiida.orm import load_node, ProcessNode
+from aiida.orm import ProcessNode, load_node
 from aiida.plugins.utils import PluginVersionProvider
 
-from .processes import futures, Process, ProcessBuilder, ProcessState
+from . import transports, utils
+from .processes import Process, ProcessBuilder, ProcessState, futures
 from .processes.calcjobs import manager
-from . import transports
-from . import utils
 
 __all__ = ('Runner',)
 
@@ -166,7 +165,7 @@ class Runner:  # pylint: disable=too-many-public-methods
         self._closed = True
 
     def instantiate_process(self, process: TYPE_RUN_PROCESS, *args, **inputs):
-        from .utils import instantiate_process
+        from .utils import instantiate_process  # pylint: disable=no-name-in-module
         return instantiate_process(self, process, *args, **inputs)
 
     def submit(self, process: TYPE_SUBMIT_PROCESS, *args: Any, **inputs: Any):
@@ -300,8 +299,6 @@ class Runner:  # pylint: disable=too-many-public-methods
         :param pk: pk of the process
         :param callback: function to be called upon process termination
         """
-        assert self.communicator is not None, 'communicator not set for runner'
-
         node = load_node(pk=pk)
         subscriber_identifier = str(uuid.uuid4())
         event = threading.Event()
@@ -319,14 +316,16 @@ class Runner:  # pylint: disable=too-many-public-methods
                 callback()
             finally:
                 event.set()
-                self.communicator.remove_broadcast_subscriber(subscriber_identifier)  # type: ignore[union-attr]
+                if self.communicator:
+                    self.communicator.remove_broadcast_subscriber(subscriber_identifier)
 
         broadcast_filter = kiwipy.BroadcastFilter(functools.partial(inline_callback, event), sender=pk)
         for state in [ProcessState.FINISHED, ProcessState.KILLED, ProcessState.EXCEPTED]:
             broadcast_filter.add_subject_filter(f'state_changed.*.{state.value}')
 
-        LOGGER.info('adding subscriber for broadcasts of %d', pk)
-        self.communicator.add_broadcast_subscriber(broadcast_filter, subscriber_identifier)
+        if self.communicator:
+            LOGGER.info('adding subscriber for broadcasts of %d', pk)
+            self.communicator.add_broadcast_subscriber(broadcast_filter, subscriber_identifier)
         self._poll_process(node, functools.partial(inline_callback, event))
 
     def get_process_future(self, pk: int) -> futures.ProcessFuture:
