@@ -11,14 +11,16 @@
 Testing infrastructure for easy testing of AiiDA plugins.
 
 """
-from contextlib import contextmanager
+import contextlib
 import os
 import shutil
 import tempfile
+import warnings
 
+from aiida.common.log import override_log_level
 from aiida.common.warnings import warn_deprecation
 from aiida.manage import configuration, get_manager
-from aiida.manage.configuration.settings import create_instance_directories
+from aiida.manage.configuration import settings
 from aiida.manage.external.postgres import Postgres
 
 __all__ = (
@@ -38,7 +40,7 @@ _DEFAULT_PROFILE_INFO = {
     'first_name': 'AiiDA',
     'last_name': 'Plugintest',
     'institution': 'aiidateam',
-    'storage_backend': 'psql_dos',
+    'storage_backend': 'core.psql_dos',
     'database_engine': 'postgresql_psycopg2',
     'database_username': 'aiida',
     'database_password': 'aiida_pw',
@@ -160,17 +162,30 @@ class ProfileManager:
 
     @staticmethod
     def clear_profile():
-        """Reset the global profile, clearing all its data and closing any open resources."""
+        """Reset the global profile, clearing all its data and closing any open resources.
+
+        If the daemon is running, it will be stopped because it might be holding on to entities that will be cleared
+        from the storage backend.
+        """
+        from aiida.engine.daemon.client import get_daemon_client
+
+        daemon_client = get_daemon_client()
+
+        if daemon_client.is_daemon_running:
+            daemon_client.stop_daemon(wait=True)
+
         manager = get_manager()
         manager.get_profile_storage()._clear(recreate_user=True)  # pylint: disable=protected-access
-        manager.reset_profile()
         manager.get_profile_storage()  # reload the storage connection
+        manager.reset_communicator()
+        manager.reset_runner()
 
     def has_profile_open(self):
         return self._profile is not None
 
-    def destroy_all(self):
-        pass
+    def destroy_all(self):  # pylint: disable=no-self-use
+        manager = get_manager()
+        manager.reset_profile()
 
 
 class TemporaryProfileManager(ProfileManager):
@@ -219,7 +234,7 @@ class TemporaryProfileManager(ProfileManager):
 
     """
 
-    def __init__(self, backend='psql_dos', pgtest=None):  # pylint: disable=super-init-not-called
+    def __init__(self, backend='core.psql_dos', pgtest=None):  # pylint: disable=super-init-not-called
         """Construct a TemporaryProfileManager
 
         :param backend: a database backend
@@ -227,8 +242,6 @@ class TemporaryProfileManager(ProfileManager):
            e.g. {'pg_ctl': '/somepath/pg_ctl'}. Should usually not be necessary.
 
         """
-        from aiida.manage.configuration import settings
-
         self.dbinfo = {}
         self.profile_info = _DEFAULT_PROFILE_INFO
         self.profile_info['storage_backend'] = backend
@@ -241,6 +254,7 @@ class TemporaryProfileManager(ProfileManager):
         self._backup = {
             'config': configuration.CONFIG,
             'config_dir': settings.AIIDA_CONFIG_FOLDER,
+            settings.DEFAULT_AIIDA_PATH_VARIABLE: os.environ.get(settings.DEFAULT_AIIDA_PATH_VARIABLE, None)
         }
 
     @property
@@ -315,7 +329,7 @@ class TemporaryProfileManager(ProfileManager):
 
         Warning: the AiiDA dbenv must not be loaded when this is called!
         """
-        from aiida.manage.configuration import Profile, settings
+        from aiida.manage.configuration import Profile
         from aiida.orm import User
 
         manager = get_manager()
@@ -324,11 +338,17 @@ class TemporaryProfileManager(ProfileManager):
             self.create_aiida_db()
 
         if not self.root_dir:
-            self.root_dir = tempfile.mkdtemp()
+            self.root_dir = tempfile.TemporaryDirectory().name  # pylint: disable=consider-using-with
         configuration.CONFIG = None
-        settings.AIIDA_CONFIG_FOLDER = self.config_dir
+
+        os.environ[settings.DEFAULT_AIIDA_PATH_VARIABLE] = self.config_dir
+
+        with warnings.catch_warnings():
+            warnings.filterwarnings('ignore', category=UserWarning)
+            # This will raise a warning that the ``.aiida`` configuration directory is created.
+            settings.set_configuration_directory()
+
         manager.unload_profile()
-        create_instance_directories()
         profile_name = self.profile_info['name']
         config = configuration.get_config(create=True)
         profile = Profile(profile_name, self.profile_dictionary)
@@ -336,16 +356,23 @@ class TemporaryProfileManager(ProfileManager):
         config.set_default_profile(profile_name).store()
         self._profile = profile
 
-        # initialise the profile
-        profile = manager.load_profile(profile_name)
-        # initialize the profile storage
-        profile.storage_cls.migrate(profile)
+        # Load the new profile and initialize the profile storage
+        with override_log_level():
+            profile = manager.load_profile(profile_name)
+            profile.storage_cls.migrate(profile)
+
         # create the default user for the profile
         created, user = User.collection.get_or_create(**get_user_dict(_DEFAULT_PROFILE_INFO))
         if created:
             user.store()
         profile.default_user_email = user.email
 
+        # Set options to suppress certain warnings
+        config.set_option('warnings.development_version', False)
+        config.set_option('warnings.rabbitmq_version', False)
+
+        config.store()
+
     def repo_ok(self):
         return bool(self.repo and os.path.isdir(os.path.dirname(self.repo)))
 
@@ -368,7 +395,7 @@ class TemporaryProfileManager(ProfileManager):
         if self.has_profile_open():
             raise TestManagerError('backend cannot be changed after setting up the environment')
 
-        valid_backends = ['psql_dos']
+        valid_backends = ['core.psql_dos']
         if backend not in valid_backends:
             raise ValueError(f'invalid backend {backend}, must be one of {valid_backends}')
         self.profile_info['backend'] = backend
@@ -395,7 +422,7 @@ class TemporaryProfileManager(ProfileManager):
 
     def destroy_all(self):
         """Remove all traces of the tests run"""
-        from aiida.manage.configuration import settings
+        super().destroy_all()
         if self.root_dir:
             shutil.rmtree(self.root_dir)
             self.root_dir = None
@@ -410,6 +437,9 @@ class TemporaryProfileManager(ProfileManager):
         if 'config_dir' in self._backup:
             settings.AIIDA_CONFIG_FOLDER = self._backup['config_dir']
 
+        if settings.DEFAULT_AIIDA_PATH_VARIABLE in self._backup and self._backup[settings.DEFAULT_AIIDA_PATH_VARIABLE]:
+            os.environ[settings.DEFAULT_AIIDA_PATH_VARIABLE] = self._backup[settings.DEFAULT_AIIDA_PATH_VARIABLE]
+
     def has_profile_open(self):
         return self._profile is not None
 
@@ -417,8 +447,8 @@ class TemporaryProfileManager(ProfileManager):
 _GLOBAL_TEST_MANAGER = TestManager()
 
 
-@contextmanager
-def test_manager(backend='psql_dos', profile_name=None, pgtest=None):
+@contextlib.contextmanager
+def test_manager(backend='core.psql_dos', profile_name=None, pgtest=None):
     """ Context manager for TestManager objects.
 
     Sets up temporary AiiDA environment for testing or reuses existing environment,
@@ -480,9 +510,9 @@ def get_test_backend_name() -> str:
             )
         backend_res = backend_profile
     else:
-        backend_res = backend_env or 'psql_dos'
+        backend_res = backend_env or 'core.psql_dos'
 
-    if backend_res in ('psql_dos',):
+    if backend_res in ('core.psql_dos',):
         return backend_res
     raise ValueError(f"Unknown backend '{backend_res}' read from AIIDA_TEST_BACKEND environment variable")
 
