@@ -22,6 +22,8 @@ from importlib_metadata import entry_points as _eps
 from aiida.common.exceptions import LoadingEntryPointError, MissingEntryPointError, MultipleEntryPointError
 from aiida.common.warnings import warn_deprecation
 
+from . import factories
+
 __all__ = ('load_entry_point', 'load_entry_point_from_string', 'parse_entry_point', 'get_entry_points')
 
 ENTRY_POINT_GROUP_PREFIX = 'aiida.'
@@ -65,6 +67,7 @@ ENTRY_POINT_GROUP_TO_MODULE_PATH_MAP = {
     'aiida.node': 'aiida.orm.nodes',
     'aiida.parsers': 'aiida.parsers.plugins',
     'aiida.schedulers': 'aiida.schedulers.plugins',
+    'aiida.storage': 'aiida.storage',
     'aiida.tools.calculations': 'aiida.tools.calculations',
     'aiida.tools.data.orbitals': 'aiida.tools.data.orbitals',
     'aiida.tools.dbexporters': 'aiida.tools.dbexporters',
@@ -88,6 +91,18 @@ DEPRECATED_ENTRY_POINTS_MAPPING = {
     'aiida.workflows': ['arithmetic.multiply_add', 'arithmetic.add_multiply'],
 }
 
+ENTRY_POINT_GROUP_FACTORY_MAPPING = {
+    'aiida.calculations': factories.CalculationFactory,
+    'aiida.data': factories.DataFactory,
+    'aiida.groups': factories.GroupFactory,
+    'aiida.parsers': factories.ParserFactory,
+    'aiida.schedulers': factories.SchedulerFactory,
+    'aiida.transports': factories.TransportFactory,
+    'aiida.tools.dbimporters': factories.DbImporterFactory,
+    'aiida.tools.data.orbital': factories.OrbitalFactory,
+    'aiida.workflows': factories.WorkflowFactory,
+}
+
 
 def parse_entry_point(group: str, spec: str) -> EntryPoint:
     """Return an entry point, given its group and spec (as formatted in the setup)"""
@@ -104,21 +119,7 @@ def validate_registered_entry_points() -> None:  # pylint: disable=invalid-name
         * The resource's type is incompatible with the entry point group that it is defined in.
 
     """
-    from . import factories
-
-    factory_mapping = {
-        'aiida.calculations': factories.CalculationFactory,
-        'aiida.data': factories.DataFactory,
-        'aiida.groups': factories.GroupFactory,
-        'aiida.parsers': factories.ParserFactory,
-        'aiida.schedulers': factories.SchedulerFactory,
-        'aiida.transports': factories.TransportFactory,
-        'aiida.tools.dbimporters': factories.DbImporterFactory,
-        'aiida.tools.data.orbital': factories.OrbitalFactory,
-        'aiida.workflows': factories.WorkflowFactory,
-    }
-
-    for entry_point_group, factory in factory_mapping.items():
+    for entry_point_group, factory in ENTRY_POINT_GROUP_FACTORY_MAPPING.items():
         entry_points = get_entry_points(entry_point_group)
         for entry_point in entry_points:
             factory(entry_point.name)
@@ -281,7 +282,9 @@ def get_entry_point(group: str, name: str) -> EntryPoint:
     found = eps().select(group=group, name=name)
     if name not in found.names:
         raise MissingEntryPointError(f"Entry point '{name}' not found in group '{group}'")
-    if len(found.names) > 1:
+    # If multiple entry points are found and they have different values we raise, otherwise if they all
+    # correspond to the same value, we simply return one of them
+    if len(found) > 1 and len(set(ep.value for ep in found)) != 1:
         raise MultipleEntryPointError(f"Multiple entry points '{name}' found in group '{group}': {found}")
     return found[name]
 
