@@ -9,7 +9,7 @@
 ###########################################################################
 # pylint: disable=no-self-use
 """"Implementation of `DbImporter` for the COD database."""
-from aiida.tools.dbimporters.baseclasses import (DbImporter, DbSearchResults, CifEntry)
+from aiida.tools.dbimporters.baseclasses import CifEntry, DbImporter, DbSearchResults
 
 
 class CodDbImporter(DbImporter):
@@ -97,7 +97,7 @@ class CodDbImporter(DbImporter):
         for value in values:
             if not isinstance(value, int) and not isinstance(value, float):
                 raise ValueError(f"incorrect value for keyword '{alias}' only integers and floats are accepted")
-        return ' OR '.join('{} BETWEEN {} AND {}'.format(key, d - precision, d + precision) for d in values)
+        return ' OR '.join(f'{key} BETWEEN {d - precision} AND {d + precision}' for d in values)
 
     length_precision = 0.001
     angle_precision = 0.001
@@ -183,7 +183,7 @@ class CodDbImporter(DbImporter):
         """
         sql_parts = ["(status IS NULL OR status != 'retracted')"]
         for key in sorted(self._keywords.keys()):
-            if key in kwargs.keys():
+            if key in kwargs:
                 values = kwargs.pop(key)
                 if not isinstance(values, list):
                     values = [values]
@@ -220,7 +220,7 @@ class CodDbImporter(DbImporter):
         Changes the database connection details.
         """
         for key in self._db_parameters:
-            if key in kwargs.keys():
+            if key in kwargs:
                 self._db_parameters[key] = kwargs.pop(key)
         if len(kwargs.keys()) > 0:
             raise NotImplementedError(
