@@ -19,12 +19,13 @@ Local transport
 ### we should instead keep track internally of the 'current working directory'
 ### in the exact same way as paramiko does already.
 
+import contextlib
 import errno
+import glob
 import io
 import os
 import shutil
 import subprocess
-import glob
 
 from aiida.transports import cli as transport_cli
 from aiida.transports.transport import Transport, TransportInternalError
@@ -48,6 +49,12 @@ class LocalTransport(Transport):
     # where the remote computer will rate limit the number of connections.
     _DEFAULT_SAFE_OPEN_INTERVAL = 0.0
 
+    # Like the connection open interval, for local transport, which should be used for localhost, one probably doesn't
+    # want to have a long polling time in most cases. Since localhost is typically used for short running jobs and tests
+    # one doesn't want to be waiting tens of seconds for a job that should last less than one second. We don't set 0 but
+    # a small finite number that should prevent the CPUs from spinning while still guaranteeing fast throughput.
+    DEFAULT_MINIMUM_JOB_POLL_INTERVAL = 0.1
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         # The `_internal_dir` will emulate the concept of working directory, as the real current working directory is
@@ -716,6 +723,7 @@ class LocalTransport(Transport):
             return False
         return os.path.isfile(os.path.join(self.curdir, path))
 
+    @contextlib.contextmanager
     def _exec_command_internal(self, command, **kwargs):  # pylint: disable=unused-argument
         """
         Executes the specified command in bash login shell.
@@ -747,7 +755,7 @@ class LocalTransport(Transport):
 
         command = bash_commmand + escape_for_bash(command)
 
-        proc = subprocess.Popen(
+        with subprocess.Popen(
             command,
             shell=True,
             stdin=subprocess.PIPE,
@@ -755,42 +763,59 @@ class LocalTransport(Transport):
             stderr=subprocess.PIPE,
             cwd=self.getcwd(),
             start_new_session=True
-        )
+        ) as process:
+            yield process
 
-        return proc.stdin, proc.stdout, proc.stderr, proc
-
-    def exec_command_wait(self, command, **kwargs):
+    def exec_command_wait_bytes(self, command, stdin=None, **kwargs):
         """
         Executes the specified command and waits for it to finish.
 
         :param command: the command to execute
 
-        :return: a tuple with (return_value, stdout, stderr) where stdout and
-                 stderr are strings.
+        :return: a tuple with (return_value, stdout, stderr) where stdout and stderr
+            are both bytes and the return_value is an int.
         """
-        stdin = kwargs.get('stdin')
-        local_stdin, _, _, local_proc = self._exec_command_internal(command)
+        with self._exec_command_internal(command) as process:
 
-        if stdin is not None:
-            if isinstance(stdin, str):
-                filelike_stdin = io.StringIO(stdin)
+            if stdin is not None:
+                # Implicitly assume that the desired encoding is 'utf-8' if I receive a string.
+                # Also, if I get a StringIO, I just read it all in memory and put it into a BytesIO.
+                # Clearly not memory effective - in this case do not use a StringIO, but pass directly a BytesIO
+                # that will be read line by line, if you have a huge stdin and care about memory usage.
+                if isinstance(stdin, str):
+                    filelike_stdin = io.BytesIO(stdin.encode('utf-8'))
+                elif isinstance(stdin, bytes):
+                    filelike_stdin = io.BytesIO(stdin)
+                elif isinstance(stdin, io.TextIOBase):
+
+                    def line_encoder(iterator, encoding='utf-8'):
+                        """Encode the iterator item by item (i.e., line by line).
+
+                        This only wraps iterating over it and not all other methods, but it's enough for its
+                        use below."""
+                        for line in iterator:
+                            yield line.encode(encoding)
+
+                    filelike_stdin = line_encoder(stdin)
+                elif isinstance(stdin, io.BufferedIOBase):
+                    filelike_stdin = stdin
+                else:
+                    raise ValueError('You can only pass strings, bytes, BytesIO or StringIO objects')
+
+                try:
+                    for line in filelike_stdin:
+                        process.stdin.write(line)  # the Popen.stdin/out/err are byte streams
+                except AttributeError:
+                    raise ValueError('stdin can only be either a string or a file-like object!')
             else:
-                filelike_stdin = stdin
+                filelike_stdin = None
 
-            try:
-                for line in filelike_stdin.readlines():
-                    local_stdin.write(line.encode('utf-8'))  # the Popen.stdin/out/err are byte streams
-            except AttributeError:
-                raise ValueError('stdin can only be either a string or a file-like object!')
-        else:
-            filelike_stdin = None
+            process.stdin.flush()
+            output_text, stderr_text = process.communicate()
 
-        local_stdin.flush()
-        output_text, stderr_text = local_proc.communicate()
+            retval = process.returncode
 
-        retval = local_proc.returncode
-
-        return retval, output_text.decode('utf-8'), stderr_text.decode('utf-8')
+        return retval, output_text, stderr_text
 
     def gotocomputer_command(self, remotedir):
         """
@@ -864,4 +889,4 @@ class LocalTransport(Transport):
         return os.path.exists(os.path.join(self.curdir, path))
 
 
-CONFIGURE_LOCAL_CMD = transport_cli.create_configure_cmd('local')
+CONFIGURE_LOCAL_CMD = transport_cli.create_configure_cmd('core.local')
